pub enum ReleaseType<BlockNumber> {
Refunded,
Locked(BlockNumber),
}Variants
Refunded
The bonded tokens are immediately sent back to the treasury, and fees await refunding
Locked(BlockNumber)
The bonded tokens are locked until the block number, and the fees can be immediately sent to the fee recipient