pub enum Call<T: Config> {
transfer_bonds_back_to_treasury {
derivation_path: u32,
hold_reason: T::RuntimeHoldReason,
},
transfer_fees_to_recipient {
derivation_path: u32,
hold_reason: T::RuntimeHoldReason,
fee_asset: AssetId,
},
// some variants omitted
}Expand description
Contains a variant per dispatchable extrinsic that this pallet has.
Variants
transfer_bonds_back_to_treasury
Transfer bonded tokens back to the treasury if conditions are met.
Description
This extrinsic allows transferring bonded tokens back to the treasury account when either:
- The release block number has been reached for time-locked bonds
- Or immediately if the release type is set to
Refunded
The function will release all tokens held under the specified hold reason and transfer them, including the existential deposit, back to the treasury account. If sub-account has all the tokens unbonded, it will transfer everything including ED back to the treasury
Parameters
origin- The origin of the call. Must be signed. Can be anyone.derivation_path- The derivation path used to calculate the bonding sub-accounthold_reason- The reason for which the tokens were held
Errors
Error::ReleaseTypeNotSet- If no release type is configured for the given derivation path and hold reasonError::TooEarlyToUnlock- If the current block is before the configured release block for locked bonds
Events
Event::BondsTransferredBackToTreasury- When tokens are successfully transferred back to treasury
transfer_fees_to_recipient
Transfer collected fees to the designated fee recipient.
Description
This extrinsic transfers all collected fees in the specified fee asset from the bonding
sub-account to the configured fee recipient. This operation is only allowed when the
release type is set to Locked, indicating that the bonds are being held legitimately
rather than awaiting refund.
Parameters
origin- The origin of the call. Must be signed. Can be anyone.derivation_path- The derivation path used to calculate the bonding sub-accounthold_reason- The reason for which the tokens were heldfee_asset- The asset ID of the fee token to transfer
Errors
Error::ReleaseTypeNotSet- If no release type is configured for the given derivation path and hold reasonError::FeeToRecipientDisallowed- If the release type is set toRefunded, which means fees should be refunded instead
Events
Event::FeesTransferredToFeeRecipient- When fees are successfully transferred to the recipient
Implementations
Sourceimpl<T: Config> Call<T>
impl<T: Config> Call<T>
Sourcepub fn new_call_variant_transfer_bonds_back_to_treasury(
derivation_path: u32,
hold_reason: T::RuntimeHoldReason,
) -> Self
pub fn new_call_variant_transfer_bonds_back_to_treasury( derivation_path: u32, hold_reason: T::RuntimeHoldReason, ) -> Self
Create a call with the variant transfer_bonds_back_to_treasury.
Sourcepub fn new_call_variant_transfer_fees_to_recipient(
derivation_path: u32,
hold_reason: T::RuntimeHoldReason,
fee_asset: AssetId,
) -> Self
pub fn new_call_variant_transfer_fees_to_recipient( derivation_path: u32, hold_reason: T::RuntimeHoldReason, fee_asset: AssetId, ) -> Self
Create a call with the variant transfer_fees_to_recipient.